/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.report.EmailReportDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.CommonDialog");
dojo.require("com.ibm.rational.report.web.core.app.view.report.SelectRecipentsDialog");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");

var CommonMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ReportMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");

/**
 * Displays the Email Report view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.report.EmailReportDialog",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/report/templates/EmailReportDialog.html"),
	
	constructor: function(args) {
		this._title = args.title;
	},
	
	postCreate: function() {
		this._initText();
		
		var self = this;

		dojo.connect(this.toBrowseButton, "onclick",
			function(e) {
				dojo.stopEvent(e);
				self._handleBrowse(self.to, ReportMessages.EMAIL_REPORT_VIEWER_TO_LABEL);
			}
		);
		
		dojo.connect(this.ccBrowseButton, "onclick",
			function(e) {
				dojo.stopEvent(e);
				self._handleBrowse(self.cc, ReportMessages.EMAIL_REPORT_VIEWER_CC_LABEL);
			}
		);
		
		this.dialog = new com.ibm.rational.report.web.core.app.internal.common.CommonDialog({
			contentNode: this.contentNode,
			primaryTitle: this._title,
			width: (dojo.isIE) ? "738px" : "703px",
			isClosable: true
		});
		this.closeButton.focus();
	},
	
	_initText: function() {
		dojox.data.dom.removeChildren(this.toLabel);
		this.toLabel.appendChild(document.createTextNode(ReportMessages.EMAIL_REPORT_VIEWER_TO_LABEL));	
		
		dojox.data.dom.removeChildren(this.ccLabel);
		this.ccLabel.appendChild(document.createTextNode(ReportMessages.EMAIL_REPORT_VIEWER_CC_LABEL));
		
		dojox.data.dom.removeChildren(this.subjectLabel);
		this.subjectLabel.appendChild(document.createTextNode(ReportMessages.EMAIL_REPORT_VIEWER_SUBJECT_LABEL));
		
		dojox.data.dom.removeChildren(this.messageLabel);
		this.messageLabel.appendChild(document.createTextNode(ReportMessages.EMAIL_REPORT_VIEWER_MESSAGE_LABEL));
		
		dojox.data.dom.removeChildren(this.toBrowseButton);
		this.toBrowseButton.appendChild(document.createTextNode(CommonMessages.BROWSE_BUTTON_LABEL));
		
		dojox.data.dom.removeChildren(this.ccBrowseButton);
		this.ccBrowseButton.appendChild(document.createTextNode(CommonMessages.BROWSE_BUTTON_LABEL));
		
		dojox.data.dom.removeChildren(this.sendButton);
		this.sendButton.appendChild(document.createTextNode(ReportMessages.EMAIL_REPORT_VIEWER_EMAIL_BUTTON));
		
		dojox.data.dom.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
	},
	
	_handleBrowse: function(control, selectedTitle) {
		var count = 1;
		var self = this;
		var selectRecipentsDialog = new com.ibm.rational.report.web.core.app.view.report.SelectRecipentsDialog(
			{availableTitle: ReportMessages.EMAIL_REPORT_VIEWER_USERS_LABEL,
			control: control, selectedTitle: selectedTitle});
		dojo.connect(selectRecipentsDialog.saveButton, "onclick", selectRecipentsDialog.dialog,
			function (e) {
				dojo.stopEvent(e);
				control.value = selectRecipentsDialog.getSelected();
				selectRecipentsDialog.close();
			}
		);	
		dojo.connect(selectRecipentsDialog.closeButton, "onclick", selectRecipentsDialog.dialog,
			function (e) {
				dojo.stopEvent(e);
				selectRecipentsDialog.close();	
			}
		);	
	},
	
	close: function() {
		this.dialog.blockerDiv.parentNode.removeChild(this.dialog.blockerDiv);
		this.dialog.close();
	}
	
});

})();